@@ -14,6 +14,8 @@
 #include <QMediaPlayer>
 #include <QPair>
 #include <QVector>
+#include <QList>
+
 
 // Konsole
 #include "Emulation.h"
@@ -42,8 +44,6 @@ class QKeyEvent;
 
 namespace Konsole
 {
-extern unsigned short vt100_graphics[32];
-
 struct CharCodes {
     // coding info
     char charset[4]; //
@@ -124,12 +124,11 @@ private:
     void resetModes();
 
     void resetTokenizer();
-#define MAX_TOKEN_LENGTH 256 // Max length of tokens (e.g. window title)
     void addToCurrentToken(uint cc);
     int tokenBufferPos;
 
 protected:
-    char32_t tokenBuffer[MAX_TOKEN_LENGTH]; // FIXME: overflow?
+    QList<char32_t> tokenBuffer;
 
 private:
 #define MAXARGS 16
@@ -181,7 +180,11 @@ private:
     enum osc {
         // https://invisible-island.net/xterm/ctlseqs/ctlseqs.html#h2-Operating-System-Commands
         ReportColors = 4,
+        CursorColor = 12,
+        Clipboard = 52,
+        KittyNotification = 99,
         ResetColors = 104,
+        ResetCursorColor = 112,
         // https://gitlab.freedesktop.org/Per_Bothner/specifications/blob/master/proposals/semantic-prompts.md
         SemanticPrompts = 133,
         // https://chromium.googlesource.com/apps/libapps/+/master/hterm/doc/ControlSequences.md#OSC
@@ -193,6 +196,8 @@ private:
     bool _ignore = false;
     int _nIntermediate = 0;
     unsigned char _intermediate[1];
+    // Used to get expected behaviour in emulated up/down movement in REPL mode.
+    int _targetCol = -1;
 
     void switchState(const ParserStates newState, const uint cc);
     void esc_dispatch(const uint cc);
@@ -250,7 +255,7 @@ private:
     void reportColor(int c, QColor color);
     void reportTerminalParms(int p);
 
-    void emulateUpDown(bool up, KeyboardTranslator::Entry entry, QByteArray &textToSend, int toCol = -1);
+    void emulateUpDown(int up, KeyboardTranslator::Entry entry, QByteArray &textToSend, int toCol = -1);
 
     // clears the screen and resizes it to the specified
     // number of columns
@@ -270,6 +275,33 @@ private:
         bool mode[MODE_total];
     };
 
+    static constexpr int NotificationActionNone = 0;
+    static constexpr int NotificationActionReport = 1;
+    static constexpr int NotificationActionFocus = 2;
+
+    enum class KittyNotificationOption {
+        None,
+        Always,
+        Unfocused,
+        Invisible,
+    };
+
+    struct KittyNotificationState {
+        qint64 serial;
+        QString applicationName;
+        QString body;
+        QString title;
+        QList<QString> iconNames;
+        KittyNotificationOption option = KittyNotificationOption::Always;
+        int urgency = 1;
+        int action = NotificationActionNone;
+        int closeSignal = 0;
+        QList<QString> buttons;
+    };
+
+    qint64 _kittyNotificationSerial = 0;
+    QMap<QString, KittyNotificationState> _kittyNotifications;
+
     TerminalState _currentModes;
     TerminalState _savedModes;
 
