@@ -17,7 +17,7 @@ namespace Konsole
  * Type of hotspot created by RegExpFilter.  The capturedTexts() method can be used to find the text
  * matched by the filter's regular expression.
  */
-class RegExpFilterHotSpot : public HotSpot
+class KONSOLEPRIVATE_EXPORT RegExpFilterHotSpot : public HotSpot
 {
 public:
     RegExpFilterHotSpot(int startLine, int startColumn, int endLine, int endColumn, const QStringList &capturedTexts);
